(define-package
  "ghc"
  2.0.0
  "Sub mode for Haskell mode"
  '((haskell-mode "13.0")))
